@@ -1,14 +1,16 @@
+from collections import OrderedDict
+
+import numpy as np
 import pytorch_lightning as pl
 import torch
-from torch.optim import lr_scheduler
 import torchvision
-from collections import OrderedDict
-from satflow.models import R2U_Net, ConvLSTM
-from satflow.models.gan import GANLoss, define_generator, define_discriminator
-from satflow.models.layers import ConditionTime
 from nowcasting_utils.models.loss import get_loss
 from pl_bolts.optimizers.lr_scheduler import LinearWarmupCosineAnnealingLR
-import numpy as np
+from torch.optim import lr_scheduler
+
+from satflow.models import ConvLSTM, R2U_Net
+from satflow.models.gan import GANLoss, define_discriminator, define_generator
+from satflow.models.layers import ConditionTime
 
 
 class CloudGAN(pl.LightningModule):
@@ -243,8 +245,7 @@ class CloudGAN(pl.LightningModule):
         images, future_images = batch
         if self.condition_time:
             return self.train_per_timestep(images, future_images, optimizer_idx, batch_idx)
-        else:
-            return self.train_all_timestep(images, future_images, optimizer_idx, batch_idx)
+        return self.train_all_timestep(images, future_images, optimizer_idx, batch_idx)
 
     def val_all_timestep(self, images, future_images, batch_idx):
         # generate images
@@ -326,8 +327,7 @@ class CloudGAN(pl.LightningModule):
         images, future_images = batch
         if self.condition_time:
             return self.val_per_timestep(images, future_images, batch_idx)
-        else:
-            return self.val_all_timestep(images, future_images, batch_idx)
+        return self.val_all_timestep(images, future_images, batch_idx)
 
     def forward(self, x, **kwargs):
         return self.generator.forward(x, **kwargs)
