@@ -1,24 +1,13 @@
-import einops
-import numpy as np
-import torch
-import torch.nn as nn
 from typing import Any, Dict
 
-from nowcasting_utils.models.base import register_model, BaseModel
+import einops
+import torch
+import torch.nn as nn
+from metnet import MetNet
+from nowcasting_dataset.consts import NWP_DATA, SATELLITE_DATA, TOPOGRAPHIC_DATA
+from nowcasting_utils.models.base import BaseModel, register_model
 from nowcasting_utils.models.loss import get_loss
 from pl_bolts.optimizers.lr_scheduler import LinearWarmupCosineAnnealingLR
-from metnet import MetNet
-from nowcasting_dataset.consts import (
-    SATELLITE_DATA,
-    SATELLITE_X_COORDS,
-    SATELLITE_Y_COORDS,
-    SATELLITE_DATETIME_INDEX,
-    NWP_DATA,
-    NWP_Y_COORDS,
-    NWP_X_COORDS,
-    TOPOGRAPHIC_DATA,
-    DATETIME_FEATURE_NAMES,
-)
 
 head_to_module = {"identity": nn.Identity()}
 
